#!/bin/sh
#
# spectrumplot.sh -- Generate Spectrum Analyzer plots
# for Scion HF radar data using read_riq Version 1.21 
# T. Bullett   
# Version 2.04  16Jan10  Terry Bullett
#
APPNAME=spectrumplot
TFMT='%F %T %Z'
REALTIME=$(date -u +"$TFMT" )
YYYY=$(date -u +%Y)
DDD=$(date -u +%j)
LOGFILE="$HOME/log/$APPNAME-$YYYY-$DDD.log"
ERRLOG="$HOME/log/$APPNAME-$YYYY-$DDD.errlog"
TMPDIR="$HOME/tmp/$APPNAME"
mkdir -p $TMPDIR

# User-adustable plot parameters
SIZE="1024,768"
FRQSPAN="[0.0:25.0]"
PWRRANGE="[0:90]"
#
export GDFONTPATH=/usr/share/fonts/truetype/msttcorefonts/

declare -i OBSTIME CLEAN NOISE EIGHT MASK SMASK SIGMAX
# Process command line switches
CLEAN=$((0))
NETCDF=$((0))
EIGHT=$((0))
NOISE=$((1))
SIGMAX=$((0))

while getopts 'a:chm:np8' OPTION
do
   case $OPTION in
      c) CLEAN=$((1)) 
         ;;
      h)
         echo "gen-sa Version 1.21"
	 echo "Plot VIPIR ionograms in total power, SNR and O/X SNR"
         echo "Optional switches"
	 echo "-a n  Plot antenna n "
	 echo "-c Clean up by deleting the temp data file"
         echo "-h Print this help message"
         echo "-m rxmask   Use rxmask for riq-ionogram"
         echo "-n Plot the noise estimate (default)"
         echo "-p Plot the peak (maximum) signal value"
         echo "-8 Plot all 8 antennas in separate plots"
	 echo ""
	 exit 0 
	 ;;
      m) MASK=$(($OPTARG))
         ;;
      n) NOISE=$((1))
         SIGMAX=$((0))
         ;;
      p) SIGMAX=$((1))
         NOISE=$((0))
	 ;;
      8) EIGHT=$((1))
         ;;
   esac
done
#
# Remove the switches from the list.
shift $((OPTIND - 1))

PLOTCOL="6"
PLOTYPE="Noise"
if (($SIGMAX)) ; then
   PLOTCOL="7"
   PLOTYPE="Max"
fi   
#
RIQFILE=$1
BFN=$(basename $RIQFILE .RIQ)
DIR=$(dirname $RIQFILE) 
TITLE=$2
# For v0 data files with no station ID in the filerm
URSI=${BFN:0:5}
# Determine the measurement time from the standard filename
YEAR=${BFN:6:4}
DAY=${BFN:10:3}
HH=${BFN:13:2}
MM=${BFN:15:2}
SS=${BFN:17:2}
#
DATESTRING="01Jan$YEAR $DAY days yesterday $HH:$MM:$SS"
let OBSTIME=$(date -u +%s --date="$DATESTRING")
OBSDATE=$(date -u +'%Y %j %T %Z'  --date="$DATESTRING" )
#
SMASK=$((2#11111111))
#
# Determine site and time variable items, especially rxmask
case $URSI in 
   BD840)
      STATION="Boulder"
      ;;
   JM91J)
      STATION="Jicamarca"
      ;;
   HAJ45)
      STATION="Hanscom"
      ;;
   WP937)
      STATION="Wallops"
      ;;
    *)
      STATION="UNKNOWN"
      ;;
esac
#
#  Over-ride the receiver mask by command line
   if [ $MASK ] ; then
      RXMASK="-m $MASK"
      BMASK=$( echo  "obase=2;$MASK" | bc)
   else
      RXMASK="-m $SMASK"
      BMASK=$( echo  "obase=2;$SMASK" | bc)
   fi
#
#  pad to 8 places
   BMASK=$(printf "%.8d\n" $BMASK)
#
if (( $EIGHT )) ; then 
   RXLIST='1 2 3 4 5 6 7 8'
   PLOTLINE='plot '
   for RX in $RXLIST ; do
      TXTFILE="$DIR/$BFN-$RX"'.sam'
      PWRIMG="$DIR/$BFN-$RX"'_sam.png'
      PLOTFILE=$TMPDIR/plot.gnu
      if (( $CLEAN )) ; then 
         rm -f $TXTFILE 
      fi
#     Inform the calling program of the files created.
      echo $TXTFILE $PWRIMG 
#     Use the readriq program to extract the plot file from the
#     raw data file.  Many user-maintained options here!
#     This is a long process; do not repeat if already done
      if [ ! -f $TXTFILE  ] ; then 
         riq_ionogram  -sa -a $RX -r1 40 $RIQFILE > $TXTFILE
#        Wallops v0: riq_ionogram  -c -bf -U $URSI  $RIQFILE > $TXTFILE
      fi 
      PL1="'$TXTFILE' using 2:$PLOTCOL title 'Rx $RX' with fsteps $RX"
      PLOTLINE="$PLOTLINE $PL1 , "
#
      cat <<EOF > $PLOTFILE
set grid
set xrange $FRQSPAN
set xtics 1
set mxtics 10  
set yrange $PWRRANGE 
set ytics 10
set mytics 10   
set title "$BFN $2 Receiver $RX   $PLOTYPE"
set xlabel "Frequency [MHz]"
set ylabel "Power [dB]"
#set label 3  "RxMask $BMASK" at screen 0.80,0.95 font "arial,10"
set term png font arial 12 size $SIZE crop 
set output "$PWRIMG"
plot "$TXTFILE" using 2:$PLOTCOL title "$PLOTYPE" with fsteps 
set output
exit
EOF
      gnuplot $PLOTFILE

#      rm -f $PLOTFILE
   done
   PLOTLINE=${PLOTLINE%%??}
   PWRIMG="$DIR/$BFN"'_sam.png'
else
#  Standard power mode for all 8 receivers summed incoherently
   TXTFILE="$DIR/$BFN"'.sam'
   PWRIMG="$DIR/$BFN"'_sam.png'
   PLOTFILE=$TMPDIR/plot.gnu
   if (( $CLEAN )) ; then 
      rm -f $TXTFILE 
   fi
#  Inform the calling program of the files created.
   echo $TXTFILE $PWRIMG 
#  Use the readriq program to extract the plot file from the
#  raw data file.  Many user-maintained options here!
#  This is a long process; do not repeat if already done
   if [ ! -f $TXTFILE  ] ; then 
      riq_ionogram  -sa -r1 40 $RXMASK $RIQFILE > $TXTFILE
#     Wallops v0: riq_ionogram  -c -bf -U $URSI  $RIQFILE > $TXTFILE
   fi 
   PLOTLINE='plot "'$TXTFILE'" using 2:'$PLOTCOL' title "'$PLOTYPE'" with fsteps '

fi

cat <<EOF > $PLOTFILE
set grid 
set xrange $FRQSPAN
set xtics 1
set mxtics 10
set yrange $PWRRANGE 
set ytics 10
set mytics 10   
set title "$BFN $2  $PLOTYPE"
set xlabel "Frequency [MHz]"
set ylabel 'Power [dB]'
set term png font arial 12 size $SIZE crop 
set output "$PWRIMG"
$PLOTLINE
set output
exit
EOF

gnuplot $PLOTFILE

#   rm -f $PLOTFILE

exit 0
